@@ -4,15 +4,9 @@
 '''
 Image assessment algorithms. Typical overlap and error computation
 measures to evaluate results from other processing units.
-
-    Change directory to provide relative paths for doctests
-    >>> import os
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-    >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
-    >>> os.chdir(datadir)
-
 '''
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 from builtins import zip, range
 
 import os
@@ -24,26 +18,32 @@ from scipy.ndimage.morphology import binary_erosion
 from scipy.spatial.distance import cdist, euclidean, dice, jaccard
 from scipy.ndimage.measurements import center_of_mass, label
 
-from .. import logging
-from ..utils.misc import package_check
+from .. import config, logging
 
-from ..interfaces.base import (BaseInterface, traits, TraitedSpec, File,
-                               InputMultiPath,
-                               BaseInterfaceInputSpec, isdefined)
-from nipype.utils import NUMPY_MMAP
+from ..interfaces.base import (
+    SimpleInterface, BaseInterface, traits, TraitedSpec, File,
+    InputMultiPath, BaseInterfaceInputSpec,
+    isdefined)
+from ..interfaces.nipy.base import NipyBaseInterface
 
-iflogger = logging.getLogger('interface')
+iflogger = logging.getLogger('nipype.interface')
 
 
 class DistanceInputSpec(BaseInterfaceInputSpec):
-    volume1 = File(exists=True, mandatory=True,
-                   desc="Has to have the same dimensions as volume2.")
+    volume1 = File(
+        exists=True,
+        mandatory=True,
+        desc="Has to have the same dimensions as volume2.")
     volume2 = File(
-        exists=True, mandatory=True,
-        desc="Has to have the same dimensions as volume1."
-    )
+        exists=True,
+        mandatory=True,
+        desc="Has to have the same dimensions as volume1.")
     method = traits.Enum(
-        "eucl_min", "eucl_cog", "eucl_mean", "eucl_wmean", "eucl_max",
+        "eucl_min",
+        "eucl_cog",
+        "eucl_mean",
+        "eucl_wmean",
+        "eucl_max",
         desc='""eucl_min": Euclidean distance between two closest points\
         "eucl_cog": mean Euclidian distance between the Center of Gravity\
         of volume1 and CoGs of volume2\
@@ -53,16 +53,15 @@ class DistanceInputSpec(BaseInterfaceInputSpec):
         to volume1 weighted by their values\
         "eucl_max": maximum over minimum Euclidian distances of all volume2\
         voxels to volume1 (also known as the Hausdorff distance)',
-        usedefault=True
-    )
+        usedefault=True)
     mask_volume = File(
         exists=True, desc="calculate overlap only within this mask.")
 
 
 class DistanceOutputSpec(TraitedSpec):
     distance = traits.Float()
-    point1 = traits.Array(shape=(3,))
-    point2 = traits.Array(shape=(3,))
+    point1 = traits.Array(shape=(3, ))
+    point2 = traits.Array(shape=(3, ))
     histogram = File()
 
 
@@ -103,23 +102,24 @@ class Distance(BaseInterface):
             np.argmin(dist_matrix), dist_matrix.shape)
         return (euclidean(set1_coordinates.T[point1, :],
                           set2_coordinates.T[point2, :]),
-                set1_coordinates.T[point1, :],
-                set2_coordinates.T[point2, :])
+                set1_coordinates.T[point1, :], set2_coordinates.T[point2, :])
 
     def _eucl_cog(self, nii1, nii2):
-        origdata1 = np.logical_and(nii1.get_data() != 0, np.logical_not(np.isnan(nii1.get_data())))
+        origdata1 = np.logical_and(nii1.get_data() != 0,
+                                   np.logical_not(np.isnan(nii1.get_data())))
         cog_t = np.array(center_of_mass(origdata1.copy())).reshape(-1, 1)
         cog_t = np.vstack((cog_t, np.array([1])))
         cog_t_coor = np.dot(nii1.affine, cog_t)[:3, :]
 
-        origdata2 = np.logical_and(nii2.get_data() != 0, np.logical_not(np.isnan(nii2.get_data())))
+        origdata2 = np.logical_and(nii2.get_data() != 0,
+                                   np.logical_not(np.isnan(nii2.get_data())))
         (labeled_data, n_labels) = label(origdata2)
 
         cogs = np.ones((4, n_labels))
 
         for i in range(n_labels):
-            cogs[:3, i] = np.array(center_of_mass(origdata2,
-                                                  labeled_data, i + 1))
+            cogs[:3, i] = np.array(
+                center_of_mass(origdata2, labeled_data, i + 1))
 
         cogs_coor = np.dot(nii2.affine, cogs)[:3, :]
 
@@ -138,6 +138,8 @@ class Distance(BaseInterface):
 
         dist_matrix = cdist(set1_coordinates.T, set2_coordinates.T)
         min_dist_matrix = np.amin(dist_matrix, axis=0)
+        import matplotlib
+        matplotlib.use(config.get('execution', 'matplotlib_backend'))
         import matplotlib.pyplot as plt
         plt.figure()
         plt.hist(min_dist_matrix, 50, normed=1, facecolor='green')
@@ -147,9 +149,7 @@ class Distance(BaseInterface):
 
         if weighted:
             return np.average(
-                min_dist_matrix,
-                weights=nii2.get_data()[origdata2].flat
-            )
+                min_dist_matrix, weights=nii2.get_data()[origdata2].flat)
         else:
             return np.mean(min_dist_matrix)
 
@@ -177,8 +177,8 @@ class Distance(BaseInterface):
         set1_coordinates = self._get_coordinates(border1, nii1.affine)
         set2_coordinates = self._get_coordinates(border2, nii2.affine)
         distances = cdist(set1_coordinates.T, set2_coordinates.T)
-        mins = np.concatenate(
-            (np.amin(distances, axis=0), np.amin(distances, axis=1)))
+        mins = np.concatenate((np.amin(distances, axis=0),
+                               np.amin(distances, axis=1)))
 
         return np.max(mins)
 
@@ -216,39 +216,52 @@ class Distance(BaseInterface):
 
 
 class OverlapInputSpec(BaseInterfaceInputSpec):
-    volume1 = File(exists=True, mandatory=True,
-                   desc='Has to have the same dimensions as volume2.')
-    volume2 = File(exists=True, mandatory=True,
-                   desc='Has to have the same dimensions as volume1.')
-    mask_volume = File(exists=True,
-                       desc='calculate overlap only within this mask.')
-    bg_overlap = traits.Bool(False, usedefault=True, mandatory=True,
-                             desc='consider zeros as a label')
+    volume1 = File(
+        exists=True,
+        mandatory=True,
+        desc='Has to have the same dimensions as volume2.')
+    volume2 = File(
+        exists=True,
+        mandatory=True,
+        desc='Has to have the same dimensions as volume1.')
+    mask_volume = File(
+        exists=True, desc='calculate overlap only within this mask.')
+    bg_overlap = traits.Bool(
+        False,
+        usedefault=True,
+        mandatory=True,
+        desc='consider zeros as a label')
     out_file = File('diff.nii', usedefault=True)
-    weighting = traits.Enum('none', 'volume', 'squared_vol', usedefault=True,
-                            desc=('\'none\': no class-overlap weighting is '
-                                  'performed. \'volume\': computed class-'
-                                  'overlaps are weighted by class volume '
-                                  '\'squared_vol\': computed class-overlaps '
-                                  'are weighted by the squared volume of '
-                                  'the class'))
-    vol_units = traits.Enum('voxel', 'mm', mandatory=True, usedefault=True,
-                            desc='units for volumes')
+    weighting = traits.Enum(
+        'none',
+        'volume',
+        'squared_vol',
+        usedefault=True,
+        desc=('\'none\': no class-overlap weighting is '
+              'performed. \'volume\': computed class-'
+              'overlaps are weighted by class volume '
+              '\'squared_vol\': computed class-overlaps '
+              'are weighted by the squared volume of '
+              'the class'))
+    vol_units = traits.Enum(
+        'voxel',
+        'mm',
+        mandatory=True,
+        usedefault=True,
+        desc='units for volumes')
 
 
 class OverlapOutputSpec(TraitedSpec):
     jaccard = traits.Float(desc='averaged jaccard index')
     dice = traits.Float(desc='averaged dice index')
-    roi_ji = traits.List(traits.Float(),
-                         desc=('the Jaccard index (JI) per ROI'))
+    roi_ji = traits.List(
+        traits.Float(), desc=('the Jaccard index (JI) per ROI'))
     roi_di = traits.List(traits.Float(), desc=('the Dice index (DI) per ROI'))
     volume_difference = traits.Float(desc=('averaged volume difference'))
-    roi_voldiff = traits.List(traits.Float(),
-                              desc=('volume differences of ROIs'))
-    labels = traits.List(traits.Int(),
-                         desc=('detected labels'))
-    diff_file = File(exists=True,
-                     desc='error map of differences')
+    roi_voldiff = traits.List(
+        traits.Float(), desc=('volume differences of ROIs'))
+    labels = traits.List(traits.Int(), desc=('detected labels'))
+    diff_file = File(exists=True, desc='error map of differences')
 
 
 class Overlap(BaseInterface):
@@ -296,8 +309,6 @@ class Overlap(BaseInterface):
         data1 = data1.astype(np.min_scalar_type(max1))
         data2 = nii2.get_data().astype(np.min_scalar_type(max1))
         data2[np.logical_or(data1 < 0, np.isnan(data1))] = 0
-        max2 = data2.max()
-        maxlabel = max(max1, max2)
 
         if isdefined(self.inputs.mask_volume):
             maskdata = nb.load(self.inputs.mask_volume).get_data()
@@ -314,8 +325,9 @@ class Overlap(BaseInterface):
             labels.insert(0, 0)
 
         for l in labels:
-            res.append(self._bool_vec_dissimilarity(data1 == l,
-                                                    data2 == l, method='jaccard'))
+            res.append(
+                self._bool_vec_dissimilarity(
+                    data1 == l, data2 == l, method='jaccard'))
             volumes1.append(scale * len(data1[data1 == l]))
             volumes2.append(scale * len(data2[data2 == l]))
 
@@ -323,7 +335,7 @@ class Overlap(BaseInterface):
         results['jaccard'] = np.array(res)
         results['dice'] = 2.0 * results['jaccard'] / (results['jaccard'] + 1.0)
 
-        weights = np.ones((len(volumes1),), dtype=np.float32)
+        weights = np.ones((len(volumes1), ), dtype=np.float32)
         if self.inputs.weighting != 'none':
             weights = weights / np.array(volumes1)
             if self.inputs.weighting == 'squared_vol':
@@ -333,13 +345,14 @@ class Overlap(BaseInterface):
         both_data = np.zeros(data1.shape)
         both_data[(data1 - data2) != 0] = 1
 
-        nb.save(nb.Nifti1Image(both_data, nii1.affine, nii1.header),
-                self.inputs.out_file)
+        nb.save(
+            nb.Nifti1Image(both_data, nii1.affine, nii1.header),
+            self.inputs.out_file)
 
         self._labels = labels
         self._ove_rois = results
-        self._vol_rois = (np.array(volumes1) -
-                          np.array(volumes2)) / np.array(volumes1)
+        self._vol_rois = (
+            np.array(volumes1) - np.array(volumes2)) / np.array(volumes1)
 
         self._dice = round(np.sum(weights * results['dice']), 5)
         self._jaccard = round(np.sum(weights * results['jaccard']), 5)
@@ -362,29 +375,44 @@ class Overlap(BaseInterface):
 
 
 class FuzzyOverlapInputSpec(BaseInterfaceInputSpec):
-    in_ref = InputMultiPath(File(exists=True), mandatory=True,
-                            desc='Reference image. Requires the same dimensions as in_tst.')
-    in_tst = InputMultiPath(File(exists=True), mandatory=True,
-                            desc='Test image. Requires the same dimensions as in_ref.')
-    weighting = traits.Enum('none', 'volume', 'squared_vol', usedefault=True,
-                            desc=('\'none\': no class-overlap weighting is '
-                                  'performed. \'volume\': computed class-'
-                                  'overlaps are weighted by class volume '
-                                  '\'squared_vol\': computed class-overlaps '
-                                  'are weighted by the squared volume of '
-                                  'the class'))
-    out_file = File('diff.nii', desc='alternative name for resulting difference-map', usedefault=True)
+    in_ref = InputMultiPath(
+        File(exists=True),
+        mandatory=True,
+        desc='Reference image. Requires the same dimensions as in_tst.')
+    in_tst = InputMultiPath(
+        File(exists=True),
+        mandatory=True,
+        desc='Test image. Requires the same dimensions as in_ref.')
+    in_mask = File(exists=True, desc='calculate overlap only within mask')
+    weighting = traits.Enum(
+        'none',
+        'volume',
+        'squared_vol',
+        usedefault=True,
+        desc=('\'none\': no class-overlap weighting is '
+              'performed. \'volume\': computed class-'
+              'overlaps are weighted by class volume '
+              '\'squared_vol\': computed class-overlaps '
+              'are weighted by the squared volume of '
+              'the class'))
+    out_file = File(
+        'diff.nii',
+        desc='alternative name for resulting difference-map',
+        usedefault=True)
 
 
 class FuzzyOverlapOutputSpec(TraitedSpec):
     jaccard = traits.Float(desc='Fuzzy Jaccard Index (fJI), all the classes')
     dice = traits.Float(desc='Fuzzy Dice Index (fDI), all the classes')
-    diff_file = File(exists=True, desc='resulting difference-map of all classes, using the chosen weighting')
-    class_fji = traits.List(traits.Float(), desc='Array containing the fJIs of each computed class')
-    class_fdi = traits.List(traits.Float(), desc='Array containing the fDIs of each computed class')
+    class_fji = traits.List(
+        traits.Float(),
+        desc='Array containing the fJIs of each computed class')
+    class_fdi = traits.List(
+        traits.Float(),
+        desc='Array containing the fDIs of each computed class')
 
 
-class FuzzyOverlap(BaseInterface):
+class FuzzyOverlap(SimpleInterface):
     """Calculates various overlap measures between two maps, using the fuzzy
     definition proposed in: Crum et al., Generalized Overlap Measures for
     Evaluation and Validation in Medical Image Analysis, IEEE Trans. Med.
@@ -408,79 +436,92 @@ class FuzzyOverlap(BaseInterface):
     output_spec = FuzzyOverlapOutputSpec
 
     def _run_interface(self, runtime):
-        ncomp = len(self.inputs.in_ref)
-        assert(ncomp == len(self.inputs.in_tst))
-        weights = np.ones(shape=ncomp)
+        # Load data
+        refdata = nb.concat_images(self.inputs.in_ref).get_data()
+        tstdata = nb.concat_images(self.inputs.in_tst).get_data()
 
-        img_ref = np.array([nb.load(fname, mmap=NUMPY_MMAP).get_data() for fname in self.inputs.in_ref])
-        img_tst = np.array([nb.load(fname, mmap=NUMPY_MMAP).get_data() for fname in self.inputs.in_tst])
+        # Data must have same shape
+        if not refdata.shape == tstdata.shape:
+            raise RuntimeError(
+                'Size of "in_tst" %s must match that of "in_ref" %s.' %
+                (tstdata.shape, refdata.shape))
 
-        msk = np.sum(img_ref, axis=0)
-        msk[msk > 0] = 1.0
-        tst_msk = np.sum(img_tst, axis=0)
-        tst_msk[tst_msk > 0] = 1.0
+        ncomp = refdata.shape[-1]
 
-        # check that volumes are normalized
-        # img_ref[:][msk>0] = img_ref[:][msk>0] / (np.sum( img_ref, axis=0 ))[msk>0]
-        # img_tst[tst_msk>0] = img_tst[tst_msk>0] / np.sum( img_tst, axis=0 )[tst_msk>0]
+        # Load mask
+        mask = np.ones_like(refdata, dtype=bool)
+        if isdefined(self.inputs.in_mask):
+            mask = nb.load(self.inputs.in_mask).get_data()
+            mask = mask > 0
+            mask = np.repeat(mask[..., np.newaxis], ncomp, -1)
+            assert mask.shape == refdata.shape
 
-        self._jaccards = []
-        volumes = []
+        # Drop data outside mask
+        refdata = refdata[mask]
+        tstdata = tstdata[mask]
 
-        diff_im = np.zeros(img_ref.shape)
+        if np.any(refdata < 0.0):
+            iflogger.warning('Negative values encountered in "in_ref" input, '
+                             'taking absolute values.')
+            refdata = np.abs(refdata)
 
-        for ref_comp, tst_comp, diff_comp in zip(img_ref, img_tst, diff_im):
-            num = np.minimum(ref_comp, tst_comp)
-            ddr = np.maximum(ref_comp, tst_comp)
-            diff_comp[ddr > 0] += 1.0 - (num[ddr > 0] / ddr[ddr > 0])
-            self._jaccards.append(np.sum(num) / np.sum(ddr))
-            volumes.append(np.sum(ref_comp))
+        if np.any(tstdata < 0.0):
+            iflogger.warning('Negative values encountered in "in_tst" input, '
+                             'taking absolute values.')
+            tstdata = np.abs(tstdata)
 
-        self._dices = 2.0 * (np.array(self._jaccards) /
-                             (np.array(self._jaccards) + 1.0))
+        if np.any(refdata > 1.0):
+            iflogger.warning('Values greater than 1.0 found in "in_ref" input, '
+                             'scaling values.')
+            refdata /= refdata.max()
 
+        if np.any(tstdata > 1.0):
+            iflogger.warning('Values greater than 1.0 found in "in_tst" input, '
+                             'scaling values.')
+            tstdata /= tstdata.max()
+
+        numerators = np.atleast_2d(
+            np.minimum(refdata, tstdata).reshape((-1, ncomp)))
+        denominators = np.atleast_2d(
+            np.maximum(refdata, tstdata).reshape((-1, ncomp)))
+
+        jaccards = numerators.sum(axis=0) / denominators.sum(axis=0)
+
+        # Calculate weights
+        weights = np.ones_like(jaccards, dtype=float)
         if self.inputs.weighting != "none":
-            weights = 1.0 / np.array(volumes)
+            volumes = np.sum((refdata + tstdata) > 0, axis=1).reshape((-1, ncomp))
+            weights = 1.0 / volumes
             if self.inputs.weighting == "squared_vol":
-                weights = weights ** 2
+                weights = weights**2
 
         weights = weights / np.sum(weights)
+        dices = 2.0 * jaccards / (jaccards + 1.0)
 
-        setattr(self, '_jaccard', np.sum(weights * self._jaccards))
-        setattr(self, '_dice', np.sum(weights * self._dices))
-
-        diff = np.zeros(diff_im[0].shape)
-
-        for w, ch in zip(weights, diff_im):
-            ch[msk == 0] = 0
-            diff += w * ch
-
-        nb.save(nb.Nifti1Image(diff, nb.load(self.inputs.in_ref[0]).affine,
-                               nb.load(self.inputs.in_ref[0]).header),
-                self.inputs.out_file)
-
+        # Fill-in the results object
+        self._results['jaccard'] = float(weights.dot(jaccards))
+        self._results['dice'] = float(weights.dot(dices))
+        self._results['class_fji'] = [float(v) for v in jaccards]
+        self._results['class_fdi'] = [float(v) for v in dices]
         return runtime
 
-    def _list_outputs(self):
-        outputs = self._outputs().get()
-        for method in ("dice", "jaccard"):
-            outputs[method] = getattr(self, '_' + method)
-        # outputs['volume_difference'] = self._volume
-        outputs['diff_file'] = os.path.abspath(self.inputs.out_file)
-        outputs['class_fji'] = np.array(self._jaccards).astype(float).tolist()
-        outputs['class_fdi'] = self._dices.astype(float).tolist()
-        return outputs
-
 
 class ErrorMapInputSpec(BaseInterfaceInputSpec):
-    in_ref = File(exists=True, mandatory=True,
-                  desc="Reference image. Requires the same dimensions as in_tst.")
-    in_tst = File(exists=True, mandatory=True,
-                  desc="Test image. Requires the same dimensions as in_ref.")
+    in_ref = File(
+        exists=True,
+        mandatory=True,
+        desc="Reference image. Requires the same dimensions as in_tst.")
+    in_tst = File(
+        exists=True,
+        mandatory=True,
+        desc="Test image. Requires the same dimensions as in_ref.")
     mask = File(exists=True, desc="calculate overlap only within this mask.")
-    metric = traits.Enum("sqeuclidean", "euclidean",
-                         desc='error map metric (as implemented in scipy cdist)',
-                         usedefault=True, mandatory=True)
+    metric = traits.Enum(
+        "sqeuclidean",
+        "euclidean",
+        desc='error map metric (as implemented in scipy cdist)',
+        usedefault=True,
+        mandatory=True)
     out_map = File(desc="Name for the output file")
 
 
@@ -509,7 +550,7 @@ class ErrorMap(BaseInterface):
         nii_ref = nb.load(self.inputs.in_ref)
         ref_data = np.squeeze(nii_ref.get_data())
         tst_data = np.squeeze(nb.load(self.inputs.in_tst).get_data())
-        assert(ref_data.ndim == tst_data.ndim)
+        assert (ref_data.ndim == tst_data.ndim)
 
         # Load mask
         comps = 1
@@ -545,11 +586,13 @@ class ErrorMap(BaseInterface):
         elif self.inputs.metric == 'euclidean':
             errvector = np.linalg.norm(diffvector, axis=1)
 
-        errvectorexp = np.zeros_like(mskvector, dtype=np.float32)  # The default type is uint8
+        errvectorexp = np.zeros_like(
+            mskvector, dtype=np.float32)  # The default type is uint8
         errvectorexp[msk_idxs] = errvector
 
         # Get averaged error
-        self._distance = np.average(errvector)  # Only average the masked voxels
+        self._distance = np.average(
+            errvector)  # Only average the masked voxels
 
         errmap = errvectorexp.reshape(mapshape)
 
@@ -584,23 +627,26 @@ class SimilarityInputSpec(BaseInterfaceInputSpec):
     volume2 = File(exists=True, desc="3D/4D volume", mandatory=True)
     mask1 = File(exists=True, desc="3D volume")
     mask2 = File(exists=True, desc="3D volume")
-    metric = traits.Either(traits.Enum('cc', 'cr', 'crl1', 'mi', 'nmi', 'slr'),
-                           traits.Callable(),
-                           desc="""str or callable
+    metric = traits.Either(
+        traits.Enum('cc', 'cr', 'crl1', 'mi', 'nmi', 'slr'),
+        traits.Callable(),
+        desc="""str or callable
 Cost-function for assessing image similarity. If a string,
 one of 'cc': correlation coefficient, 'cr': correlation
 ratio, 'crl1': L1-norm based correlation ratio, 'mi': mutual
 information, 'nmi': normalized mutual information, 'slr':
 supervised log-likelihood ratio. If a callable, it should
 take a two-dimensional array representing the image joint
-histogram as an input and return a float.""", usedefault=True)
+histogram as an input and return a float.""",
+        usedefault=True)
 
 
 class SimilarityOutputSpec(TraitedSpec):
-    similarity = traits.List(traits.Float(desc="Similarity between volume 1 and 2, frame by frame"))
+    similarity = traits.List(
+        traits.Float(desc="Similarity between volume 1 and 2, frame by frame"))
 
 
-class Similarity(BaseInterface):
+class Similarity(NipyBaseInterface):
     """Calculates similarity between two 3D or 4D volumes. Both volumes have to be in
     the same coordinate system, same space within that coordinate system and
     with the same voxel dimensions.
@@ -623,19 +669,8 @@ class Similarity(BaseInterface):
 
     input_spec = SimilarityInputSpec
     output_spec = SimilarityOutputSpec
-    _have_nipy = True
-
-    def __init__(self, **inputs):
-        try:
-            package_check('nipy')
-        except Exception as e:
-            self._have_nipy = False
-        super(Similarity, self).__init__(**inputs)
 
     def _run_interface(self, runtime):
-        if not self._have_nipy:
-            raise RuntimeError('nipy is not installed')
-
         from nipy.algorithms.registration.histogram_registration import HistogramRegistration
         from nipy.algorithms.registration.affine import Affine
 
@@ -652,7 +687,8 @@ class Similarity(BaseInterface):
             vols2 = nb.four_to_three(vol2_nii)
 
         if dims < 2 or dims > 4:
-            raise RuntimeError('Image dimensions not supported (detected %dD file)' % dims)
+            raise RuntimeError(
+                'Image dimensions not supported (detected %dD file)' % dims)
 
         if isdefined(self.inputs.mask1):
             mask1 = nb.load(self.inputs.mask1).get_data() == 1
@@ -667,11 +703,12 @@ class Similarity(BaseInterface):
         self._similarity = []
 
         for ts1, ts2 in zip(vols1, vols2):
-            histreg = HistogramRegistration(from_img=ts1,
-                                            to_img=ts2,
-                                            similarity=self.inputs.metric,
-                                            from_mask=mask1,
-                                            to_mask=mask2)
+            histreg = HistogramRegistration(
+                from_img=ts1,
+                to_img=ts2,
+                similarity=self.inputs.metric,
+                from_mask=mask1,
+                to_mask=mask2)
             self._similarity.append(histreg.eval(Affine()))
 
         return runtime
