@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 from future import standard_library
 standard_library.install_aliases()
@@ -13,11 +14,12 @@ import subprocess
 COMMIT_INFO_FNAME = 'COMMIT_INFO.txt'
 PY3 = sys.version_info[0] >= 3
 
+
 def pkg_commit_hash(pkg_path):
     ''' Get short form of commit hash given directory `pkg_path`
 
     There should be a file called 'COMMIT_INFO.txt' in `pkg_path`.  This is a
-    file in INI file format, with at least one section: ``commit hash``, and two
+    file in INI file format, with at least one section: ``commit hash`` and two
     variables ``archive_subst_hash`` and ``install_hash``.  The first has a
     substitution pattern in it which may have been filled by the execution of
     ``git archive`` if this is an archive generated that way.  The second is
@@ -47,10 +49,7 @@ def pkg_commit_hash(pkg_path):
     pth = os.path.join(pkg_path, COMMIT_INFO_FNAME)
     if not os.path.isfile(pth):
         raise IOError('Missing commit info file %s' % pth)
-    if PY3:
-        cfg_parser = configparser.RawConfigParser()
-    else:
-        cfg_parser = configparser.ConfigParser()
+    cfg_parser = configparser.RawConfigParser()
     with open(pth, encoding='utf-8') as fp:
         cfg_parser.readfp(fp)
     archive_subst = cfg_parser.get('commit hash', 'archive_subst_hash')
@@ -60,10 +59,12 @@ def pkg_commit_hash(pkg_path):
     if install_subst != '':
         return 'installation', install_subst
     # maybe we are in a repository
-    proc = subprocess.Popen('git rev-parse --short HEAD',
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE,
-                            cwd=pkg_path, shell=True)
+    proc = subprocess.Popen(
+        'git rev-parse --short HEAD',
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        cwd=pkg_path,
+        shell=True)
     repo_commit, _ = proc.communicate()
     if repo_commit:
         if PY3:
